==> conf-ini-g-2023.23.tar.gz: conf-ini-g-2023.23/conf_ini_g/interface/window/component/parameter/type.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from types import NoneType
from typing import Sequence

from babelwidget.main import backend_t, choices_list_wgt_h
from str_to_obj.type.hint_tree import hint_tree_t


def TypeSelector(
    hints: Sequence[hint_tree_t], backend: backend_t, /
) -> choices_list_wgt_h:
    """"""
    output = backend.choice_menu_wgt_t()

    for hint in hints:
        # Here, it is important that hint trees cannot have an OR-node with an OR-node
        # child so that hint.type has a valid value.
        if hint is NoneType:
            output.addItem("None")
        else:
            output.addItem(hint.type.__name__)

    return output

==> conf-ini-g-2023.25.tar.gz: conf-ini-g-2023.25/conf_ini_g/interface/window/component/parameter/type.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from types import NoneType
from typing import Sequence

from babelwidget.main import backend_t
from babelwidget.main import dropdown_choice_h as dropdown_choice_wgt_h
from str_to_obj.type.hint_tree import hint_tree_t


def TypeSelector(
    hints: Sequence[hint_tree_t], backend: backend_t, /
) -> dropdown_choice_wgt_h:
    """"""
    output = backend.dropdown_choice_t()

    for hint in hints:
        # Here, it is important that hint trees cannot have an OR-node with an OR-node
        # child so that hint.type has a valid value.
        if hint is NoneType:
            output.addItem("None")
        else:
            output.addItem(hint.type.__name__)

    return output
